@@ -1,7 +1,8 @@
 GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, ylabel = NA,
-                      size = 1.1, grid = TRUE, color = TRUE, linlab = NA, class = NA, 
-                      posleg = 2, boxleg = TRUE, axesvar = TRUE, axes = TRUE, numrot = 200, 
-                      choicerot = NA, savepicture = FALSE) {
+                      size = 1.1, grid = TRUE, color = TRUE, linlab = NA, class = NA,  
+                      classcolor = NA, posleg = 2, boxleg = TRUE, axesvar = TRUE, 
+                      axes = TRUE, numrot = 200, choicerot = NA, savptc = FALSE, 
+                      width = 3236, height = 2000, res = 300) {
   
   # Esta funcao executa a rotacao dos dados multivariados em baixa dimensao
   # basea-se nos artigos de: Asimov, D. . The Grand Tour: A Tool for Viewing
@@ -27,6 +28,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
   # color   - Graficos coloridos (default = TRUE).
   # linlab  - Vetor com os rotulos para as observacoes.
   # class   - Vetor com os nomes das classes dos dados.
+  # classcolor - Vetor com as cores das classes.
   # posleg  - 0 sem legenda,
   #           1 para legenda no canto superior esquerdo,
   #           2 para legenda no canto superior direito (default),
@@ -38,15 +40,18 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
   # numrot  - Numero de rotacoes (default = 200).
   #           Se method = "Interpolation", numrot representara o angulo de rotacao.
   # choicerot - Escolhe rotacao especifica e apresenta na tela,
-  #             ou salva a imagem se savepicture = TRUE.
-  # savepicture - Salva as imagens dos graficos em arquivos (default = FALSE).
+  #             ou salva a imagem se savptc = TRUE.
+  # savptc - Salva as imagens dos graficos em arquivos (default = FALSE).
+  # width  - Largura do grafico quanto savptc = TRUE (defaul = 3236).
+  # height - Altura do grafico quanto savptc = TRUE (default = 2000).
+  # res    - Resolucao nominal em ppi do grafico quanto savptc = TRUE (default = 300).
   
   # Retorna:
   # Graficos com as rotacoes.
   # proj.data  - Dados projetados.
   # vector.opt - Vetor projecao.
   # method     - Metodo usado no Grand Tour.
-
+  
   if (!is.data.frame(data))
      stop("'data' input is incorrect, it should be of type data frame. Verify!")
 
@@ -101,8 +106,17 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         stop("numrot < choicerot, numrot should be greater than or equal to choicerot. Verify!")
   }
 
-  if (!is.logical(savepicture))
-     stop("'savepicture' input is incorrect, it should be TRUE or FALSE. Verify!")
+  if (!is.logical(savptc))
+     stop("'savptc' input is incorrect, it should be TRUE or FALSE. Verify!")
+
+  if (!is.numeric(width) || width <= 0)
+     stop("'width' input is incorrect, it should be numerical and greater than zero. Verify!")
+  
+  if (!is.numeric(height) || height <= 0)
+     stop("'height' input is incorrect, it should be numerical and greater than zero. Verify!")
+  
+  if (!is.numeric(res) || res <= 0)
+     stop("'res' input is incorrect, it should be numerical and greater than zero. Verify!")
   
   if (!is.character(xlabel) && !is.na(xlabel[1]))
      stop("'xlabel' input is incorrect, it should be of type character or string. Verify!")
@@ -111,10 +125,10 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
      stop("'ylabel' input is incorrect, it should be of type character or string. Verify!")
   
   if (is.na(xlabel[1]))
-     xlabel = "X-Axis" 
+     xlabel = "X-axis" 
   
   if (is.na(ylabel[1]))
-     ylabel = "Y-Axis"
+     ylabel = "Y-axis"
 
   if (posleg==1) posleg = "topleft"   # posicao das legendas nos graficos
   if (posleg==2) posleg = "topright"
@@ -127,12 +141,16 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
   
   Num.class = 0
   if (!is.na(class[1])) {
-    class.Table <- table(class)       # cria tabela com as quantidade dos elementos das classes
+    class.Table <- table(class)        # cria tabela com as quantidade dos elementos das classes
     class.Names <- names(class.Table)  # nomes das classses
     Num.class   <- length(class.Table) # numero de classes
     NomeLinhas  <- as.matrix(class)
   } 
   
+  if (Num.class != 0 && length(classcolor) != Num.class && !is.na(classcolor) ||
+      Num.class == 0 && length(classcolor) != 1 && !is.na(classcolor))
+     stop("'classcolor' input is incorrect, it should be in an amount equal to the number of classes in 'class'. Verify!")
+  
   if (method == "TORUS") {
     
     # O codigo seguinte foi transladado do codigo em Matlab encontrado no Livro de
@@ -159,7 +177,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     
     numrot <- ifelse(is.na(choicerot[1]), numrot, choicerot)
     
-    if (savepicture) {
+    if (savptc) {
       cat("\014") # limpa a tela
       cat("\n\n Saving graphics to hard disk. Wait for the end!")
     }
@@ -189,7 +207,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
       if (is.na(choicerot[1]) || choicerot == i) {
         
-        if (savepicture) png(filename = paste("Picture ", i," - Method", method,".png",step="")) # salva os graficos em arquivos
+        if (savptc) png(filename = paste("Picture ", i," - Method", method,".png",step=""), width = width, height = height, res = res) # salva os graficos em arquivos
         
         maxX = max(proj.data[, 1], A[,1])
         minX = min(proj.data[, 1], A[,1])
@@ -198,15 +216,18 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         
         Tit <- ifelse(!is.character(title) || is.na(title[1]), paste("Rotation:", i), title)
         
+        if (!is.na(classcolor[1])) {
+           cor.classe <- classcolor
+        }
+        else { cor.classe <- c("blue") }
+        
         if (Num.class == 0) {
           
            plot(proj.data, # coordenadas do grafico
                 xlab = xlabel, # Nomeia Eixo X
                 ylab = ylabel, # Nomeia Eixo Y
-                type = "n", # nao plota pontos
-                main = Tit, # Titulo para o grafico
-                # asp  = 1,   # Aspecto do Grafico
-                # axes = F,   # elimina os eixos
+                type = "n",    # nao plota pontos
+                main = Tit,    # Titulo para o grafico
                 xlim = c(minX,maxX), # dimensao eixo X
                 ylim = c(minY,maxY)) # dimensao eixo Y
           
@@ -224,16 +245,16 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
           
            points(proj.data, # coordenadas do grafico
                   pch  = 16,  # formato dos pontos
-                  col = ifelse(color, "Blue", "Black"))
+                  cex = size,  # Tamanho dos pontos 
+                  col = ifelse(color, cor.classe, "Black"))
           
         } else {
           
           plot(0,0, # cria grafico para as coordenadas linhas x e colunas y
                xlab = xlabel, # Nomeia Eixo X
                ylab = ylabel, # Nomeia Eixo Y
-               main = Tit,  # Titulo
-               # asp  = 1,  # Aspecto do Grafico
-               type = "n", # nao plota pontos
+               main = Tit,    # Titulo
+               type = "n",    # nao plota pontos
                xlim = c(minX,maxX), # dimensao eixo X
                ylim = c(minY,maxY), # dimensao eixo Y
                col  = ifelse(color,"red","black"))  # Cor dos pontos
@@ -255,8 +276,11 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
           for (k in 1:Num.class) {
             
             Point.Form <- Init.Form + k # fomato dos pontos de cada classe
-            
-            cor1 <- ifelse(color, cor + k, "black")
+    
+            if (!is.na(classcolor[1])) {
+               cor1 <- ifelse(color, cor.classe[k], "black")
+            }
+            else { cor1 <- ifelse(color, cor + k, "black") }
             
             Point.data <- proj.data[which(class == class.Names[k]),]
             
@@ -294,15 +318,21 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
           
           Init.Form <- 15 # codigo formato ponto inicial
           
-          color_b <- cor # colore as letras das legendas e suas representacoes no grafico
+          cor <- ifelse(color, 2, 1)
           
-          if (color) color_b = cor:(cor + Num.class)
+          if (color) {
+             if (!is.na(classcolor[1])) {
+                color_b <- classcolor
+             }
+             else { color_b <- cor:(cor + Num.class) }
+          }
+          else { color_b <- cor }
           
           legend(posleg, class.Names, pch = (Init.Form):(Init.Form + Num.class), col = color_b,
                  text.col = color_b, bty = boxleg, text.font = 6, y.intersp = 0.8, xpd = TRUE) # cria a legenda
         }
         
-        if (savepicture) dev.off()
+        if (savptc) { box(col = 'white'); dev.off() }
         
         Sys.sleep(0.05) # tempo entre as plotagens dos graficos
         
@@ -312,7 +342,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
     }
     
-    if (savepicture) cat("\n \n End!")
+    if (savptc) cat("\n \n End!")
     
   }
   
@@ -336,7 +366,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     a <- matrix(0, p, 1) # matriz de rotacao
     b <- matrix(0, p, 1) # matriz de rotacao
     
-    if (savepicture) {
+    if (savptc) {
        cat("\014") # limpa a tela
        cat("\n\n Saving graphics to hard disk. Wait for the end!")
     }
@@ -363,7 +393,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
       if (is.na(choicerot[1]) || choicerot == i) {
         
-        if (savepicture) png(filename = paste("Picture ", i," - Method", method,".png",step="")) # salva os graficos em arquivos
+        if (savptc) png(filename = paste("Picture ", i," - Method", method,".png",step=""), width = width, height = height, res = res) # salva os graficos em arquivos
         
         maxX = max(proj.data[, 1], A[,1])
         minX = min(proj.data[, 1], A[,1])
@@ -372,15 +402,18 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         
         Tit <- ifelse(!is.character(title) || is.na(title[1]), paste("Rotation:", i), title)
         
+        if (!is.na(classcolor[1])) {
+           cor.classe <- classcolor
+        }
+        else { cor.classe <- c("blue") }
+        
         if (Num.class == 0) {
           
            plot(proj.data, # coordenadas do grafico
                 xlab = xlabel, # Nomeia Eixo X
                 ylab = ylabel, # Nomeia Eixo Y
-                type = "n", # nao plota pontos
-                main = Tit, # Titulo para o grafico
-                # asp  = 1,   # Aspecto do Grafico
-                # axes = F,   # elimina os eixos
+                type = "n",    # nao plota pontos
+                main = Tit,    # Titulo para o grafico
                 xlim = c(minX,maxX), # dimensao eixo X
                 ylim = c(minY,maxY)) # dimensao eixo Y
           
@@ -398,16 +431,16 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
           
            points(proj.data, # coordenadas do grafico
                   pch  = 16,  # formato dos pontos
-                  col = ifelse(color, "Blue", "Black"))
-          
+                  cex = size,  # Tamanho dos pontos 
+                  col = ifelse(color, cor.classe, "Black"))
+           
         } else {
           
           plot(0,0, # cria grafico para as coordenadas linhas x e colunas y
                xlab = xlabel, # Nomeia Eixo X
                ylab = ylabel, # Nomeia Eixo Y
-               main = Tit,  # Titulo
-               # asp  = 1,  # Aspecto do Grafico
-               type = "n", # nao plota pontos
+               main = Tit,    # Titulo
+               type = "n",    # nao plota pontos
                xlim = c(minX,maxX), # dimensao eixo X
                ylim = c(minY,maxY), # dimensao eixo Y
                col  = ifelse(color,"red","black"))  # Cor dos pontos
@@ -430,7 +463,10 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
             
             Point.Form <- Init.Form + k # fomato dos pontos de cada classe
             
-            cor1 <- ifelse(color, cor + k, "black")
+            if (!is.na(classcolor[1])) {
+               cor1 <- ifelse(color, cor.classe[k], "black")
+            }
+            else { cor1 <- ifelse(color, cor + k, "black") }
             
             Point.data <- proj.data[which(class == class.Names[k]),]
             
@@ -468,15 +504,21 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
           
           Init.Form <- 15 # codigo formato ponto inicial
           
-          color_b <- cor # colore as letras das legendas e suas representacoes no grafico
+          cor <- ifelse(color, 2, 1)
           
-          if (color) color_b = cor:(cor + Num.class)
+          if (color) {
+             if (!is.na(classcolor[1])) {
+                color_b <- classcolor
+             }
+             else { color_b <- cor:(cor + Num.class) }
+          }
+          else { color_b <- cor }
           
           legend(posleg, class.Names, pch = (Init.Form):(Init.Form + Num.class), col = color_b,
                  text.col = color_b, bty = boxleg, text.font = 6, y.intersp = 0.8, xpd = TRUE) # cria a legenda
         }
         
-        if (savepicture) dev.off()
+        if (savptc) { box(col = 'white'); dev.off() }
         
         Sys.sleep(0.05) # tempo entre as plotagens dos graficos
         
@@ -486,7 +528,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
     }
     
-    if (savepicture) cat("\n \n End!")
+    if (savptc) cat("\n \n End!")
     
   }  
   
@@ -523,7 +565,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     # iguala o numero de colunas dos vetores caso sejam diferentes
     if (length(v1) != length(v2)) {
       if (length(v1) < length(v2)) {
-        Vector1 <- cbind(Vector1,Vector2[,1])
+         Vector1 <- cbind(Vector1,Vector2[,1])
       } else Vector2 <- cbind(Vector2,Vector1[,1])
     }
     
@@ -531,7 +573,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     
     numrot <- ifelse(is.na(choicerot[1]), numrot, choicerot)
     
-    if (savepicture) {
+    if (savptc) {
        cat("\014") # limpa a tela 
        cat("\n\n Saving graphics to hard disk. Wait for the end!")
     }
@@ -546,7 +588,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
       if (is.na(choicerot[1]) || choicerot == i) {
         
-        if (savepicture) png(filename = paste("Picture ", i," - Method", method,".png",step="")) # salva os graficos em arquivos
+        if (savptc) png(filename = paste("Picture ", i," - Method", method,".png",step=""), width = width, height = height, res = res) # salva os graficos em arquivos
         
         maxX = max(proj.data[, 1])
         minX = min(proj.data[, 1])
@@ -555,15 +597,18 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         
         Tit <- ifelse(!is.character(title) || is.na(title[1]), paste("Rotation:", i), title)
         
+        if (!is.na(classcolor[1])) {
+           cor.classe <- classcolor
+        }
+        else { cor.classe <- c("blue") }
+        
         if (Num.class == 0) {
           
            plot(proj.data, # coordenadas do grafico
                 xlab = xlabel, # Nomeia Eixo X
                 ylab = ylabel, # Nomeia Eixo Y
-                type = "n", # nao plota pontos
-                main = Tit, # Titulo para o grafico
-                # asp  = 1,   # Aspecto do Grafico
-                # axes = F,   # elimina os eixos
+                type = "n",    # nao plota pontos
+                main = Tit,    # Titulo para o grafico
                 xlim = c(minX,maxX), # dimensao eixo X
                 ylim = c(minY,maxY)) # dimensao eixo Y
           
@@ -581,19 +626,19 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
           
            points(proj.data, # coordenadas do grafico
                   pch  = 16,  # formato dos pontos
-                  col = ifelse(color, "Blue", "Black"))
+                  cex = size,  # Tamanho dos pontos 
+                  col = ifelse(color, cor.classe, "Black"))
           
         } else {
           
           plot(0,0, # cria grafico para as coordenadas linhas x e colunas y
                xlab = xlabel, # Nomeia Eixo X
                ylab = ylabel, # Nomeia Eixo Y
-               main = Tit, # Titulo
-               # asp  = 1,   # Aspecto do Grafico
-               type = "n", # nao plota pontos
+               main = Tit,    # Titulo
+               type = "n",    # nao plota pontos
                xlim = c(minX,maxX), # dimensao eixo X
-               ylim = c(minY,maxY), # dimensao eixo Y
-               col  = ifelse(color,"red","black"))  # Cor dos pontos
+               ylim = c(minY,maxY)) # dimensao eixo Y
+               # col  = ifelse(color,"red","black"))  # Cor dos pontos
           
           if (grid) {
             
@@ -613,7 +658,10 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
             
             Point.Form <- Init.Form + k # fomato dos pontos de cada classe
             
-            cor1 <- ifelse(color, cor + k, "black")
+            if (!is.na(classcolor[1])) {
+               cor1 <- ifelse(color, cor.classe[k], "black")
+            }
+            else { cor1 <- ifelse(color, cor + k, "black") }
             
             Point.data <- proj.data[which(class == class.Names[k]),]
             
@@ -648,15 +696,21 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
           
           Init.Form <- 15 # codigo formato ponto inicial
           
-          color_b <- cor # colore as letras das legendas e suas representacoes no grafico
+          cor <- ifelse(color, 2, 1)
           
-          if (color) color_b = cor:(cor + Num.class)
+          if (color) {
+             if (!is.na(classcolor[1])) {
+                color_b <- classcolor
+             }
+             else { color_b <- cor:(cor + Num.class) }
+          }
+          else { color_b <- cor }
           
           legend(posleg, class.Names, pch = (Init.Form):(Init.Form + Num.class), col = color_b,
                  text.col = color_b, bty = boxleg, text.font = 6, y.intersp = 0.8, xpd = TRUE) # cria a legenda
         }
         
-        if (savepicture) dev.off()
+        if (savptc) { box(col = 'white'); dev.off() }
         
         Sys.sleep(0.05) # tempo entre as plotagens dos graficos
         
@@ -670,7 +724,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     
     proj.data <- proj.data[1:n,1:d] # dados projetados
     
-    if (savepicture) cat("\n \n End!")
+    if (savptc) cat("\n \n End!")
     
   }
   
